@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Any, List, Optional
+from typing import List, Optional
 
 from pydantic import BaseModel
 
@@ -34,6 +34,8 @@ class ValidBeforeType(str, Enum):
 
 class BoardType(str, Enum):
     Futures = "FUT"
+    ZLG = "ZLG"
+    TQBR = "TQBR"
 
 
 class OrdersRequestModel(BaseModel):
