@@ -1,6 +1,7 @@
 from typing import Optional, Union
 
 from finam.base_client.base import BaseClient
+from finam.exceptions import FinamTradeApiError
 from finam.models import ErrorBodyModel
 from finam.securities.model import Security, SecurityResponseModel
 
@@ -13,7 +14,8 @@ class SecurityClient(BaseClient):
     async def get_data(self, code: Optional[str] = None) -> Union[SecurityResponseModel, Security, ErrorBodyModel]:
         response, ok = await self._exec_request(self.RequestMethod.GET, self._url)
         if not ok:
-            return ErrorBodyModel(**response)
+            err = ErrorBodyModel(**response)
+            raise FinamTradeApiError(f"{err.error.code} | {err.error.data} | {err.error.message}")
         s = SecurityResponseModel(**response)
         if code:
             for security in s.data.securities:
